define(
//begin v1.x content
({
	smiley: "Inserir ícone emotivo",
	emoticonSmile: "sorriso",
	emoticonLaughing: "riso",
	emoticonWink: "piscadela",
	emoticonGrin: "gargalhada",
	emoticonCool: "com estilo",
	emoticonAngry: "zangado",
	emoticonHalf: "céptico",
	emoticonEyebrow: "desconfiado",
	emoticonFrown: "triste",
	emoticonShy: "tímido",
	emoticonGoofy: "engraçado",
	emoticonOops: "ups",
	emoticonTongue: "língua de fora",
	emoticonIdea: "ideia",
	emoticonYes: "sim",
	emoticonNo: "não",
	emoticonAngel: "anjo",
	emoticonCrying: "a chorar"
})

//end v1.x content
);
